@@ -12,7 +12,7 @@ __all__ = [  # noqa: F405
     'TASKS_LOCAL',
     # from .base
     'task_zip_release',
-    # from .code_tag_collector
+    # from .code_tags
     'task_collect_code_tags',
     # from .doc
     'task_cl_bump_pre',
@@ -23,12 +23,15 @@ __all__ = [  # noqa: F405
     'task_open_docs',
     # from .lint
     'task_auto_format',
+    'task_format_py',
+    'task_format_toml',
     'task_lint_critical_only',
     'task_lint_project',
     'task_lint_python',
     'task_pre_commit_hooks',
     'task_radon_lint',
     'task_security_checks',
+    'task_static_checks',
     # from .packaging
     'task_check_for_stale_packages',
     'task_check_license',
@@ -44,7 +47,7 @@ __all__ = [  # noqa: F405
     'task_ptw_current',
     'task_ptw_ff',
     'task_ptw_marker',
-    'task_ptw_not_chrome',
+    'task_ptw_not_interactive',
     'task_test_all',
     'task_test_keyword',
     'task_test_marker',
@@ -54,7 +57,7 @@ __all__ = [  # noqa: F405
 from getpass import getuser
 
 from .base import task_zip_release  # noqa: F401
-from .code_tag_collector import task_collect_code_tags  # noqa: F401
+from .code_tags import task_collect_code_tags  # noqa: F401
 from .doc import *  # noqa: F401,F403,H303. lgtm [py/polluting-import]
 from .lint import *  # noqa: F401,F403,H303. lgtm [py/polluting-import]
 from .packaging import *  # noqa: F401,F403,H303. lgtm [py/polluting-import]
@@ -77,6 +80,7 @@ TASKS_LOCAL = [
     'check_for_stale_packages',
     'pre_commit_hooks',
     'lint_project',
+    'static_checks',
     'security_checks',
     'check_types',
 ]
